API Documentation
=================

The ``GenotypePhenotypeMap`` is the main entry point to the gpmap package. Load
in your data using the ``read`` methods attached to this object. The following
subpackages include various objects to analyze this object.

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   gpmap
   gpmap.simulate

GenotypePhenotypeMap
--------------------

.. automodule:: gpmap.gpm
    :members:
    :undoc-members:
    :show-inheritance:
